@@ -1,9 +1,10 @@
 #include "openbox/actions.h"
 #include "openbox/stacking.h"
+#include "openbox/window.h"
 
 static gboolean run_func(ObActionsData *data, gpointer options);
 
-void action_raise_startup()
+void action_raise_startup(void)
 {
     actions_register("Raise",
                      NULL, NULL,
