@@ -18,6 +18,7 @@
 */
 
 #include "focus_cycle_popup.h"
+#include "focus_cycle.h"
 #include "popup.h"
 #include "client.h"
 #include "screen.h"
@@ -75,15 +76,12 @@ static ObFocusCyclePopup popup;
 /*! This popup shows a single window */
 static ObIconPopup *single_popup;
 
-static gchar *popup_get_name (ObClient *c);
-static void   popup_setup    (ObFocusCyclePopup *p,
-                              gboolean create_targets,
-                              gboolean iconic_windows,
-                              gboolean all_desktops,
-                              gboolean dock_windows,
-                              gboolean desktop_windows);
-static void   popup_render   (ObFocusCyclePopup *p,
-                              const ObClient *c);
+static gchar   *popup_get_name (ObClient *c);
+static gboolean popup_setup    (ObFocusCyclePopup *p,
+                                gboolean create_targets,
+                                gboolean refresh_targets);
+static void     popup_render   (ObFocusCyclePopup *p,
+                                const ObClient *c);
 
 static Window create_window(Window parent, guint bwidth, gulong mask,
                             XSetWindowAttributes *attr)
@@ -162,12 +160,34 @@ void focus_cycle_popup_shutdown(gboolean reconfig)
     RrAppearanceFree(popup.a_bg);
 }
 
-static void popup_setup(ObFocusCyclePopup *p, gboolean create_targets,
-                        gboolean iconic_windows, gboolean all_desktops,
-                        gboolean dock_windows, gboolean desktop_windows)
+static void popup_target_free(ObFocusCyclePopupTarget *t)
+{
+    RrImageUnref(t->icon);
+    g_free(t->text);
+    XDestroyWindow(ob_display, t->win);
+    g_free(t);
+}
+
+static gboolean popup_setup(ObFocusCyclePopup *p, gboolean create_targets,
+                            gboolean refresh_targets)
 {
     gint maxwidth, n;
     GList *it;
+    GList *rtargets; /* old targets for refresh */
+    GList *rtlast;
+    gboolean change;
+
+    if (refresh_targets) {
+        rtargets = p->targets;
+        rtlast = g_list_last(rtargets);
+        p->targets = NULL;
+        p->n_targets = 0;
+        change = FALSE;
+    }
+    else {
+        rtargets = rtlast = NULL;
+        change = TRUE;
+    }
 
     g_assert(p->targets == NULL);
     g_assert(p->n_targets == 0);
@@ -181,40 +201,79 @@ static void popup_setup(ObFocusCyclePopup *p, gboolean create_targets,
     for (it = g_list_last(focus_order); it; it = g_list_previous(it)) {
         ObClient *ft = it->data;
 
-        if (focus_valid_target(ft, TRUE,
-                               iconic_windows,
-                               all_desktops,
-                               dock_windows,
-                               desktop_windows,
-                               FALSE))
-        {
-            gchar *text = popup_get_name(ft);
+        if (focus_cycle_valid(ft)) {
+            GList *rit;
 
-            /* measure */
-            p->a_text->texture[0].data.text.string = text;
-            maxwidth = MAX(maxwidth, RrMinWidth(p->a_text));
+            /* reuse the target if possible during refresh */
+            for (rit = rtlast; rit; rit = g_list_previous(rit)) {
+                ObFocusCyclePopupTarget *t = rit->data;
+                if (t->client == ft) {
+                    if (rit == rtlast)
+                        rtlast = g_list_previous(rit);
+                    rtargets = g_list_remove_link(rtargets, rit);
 
-            if (!create_targets)
-                g_free(text);
-            else {
-                ObFocusCyclePopupTarget *t = g_new(ObFocusCyclePopupTarget, 1);
+                    p->targets = g_list_concat(rit, p->targets);
+                    ++n;
 
-                t->client = ft;
-                t->text = text;
-                t->icon = client_icon(t->client);
-                RrImageRef(t->icon); /* own the icon so it won't go away */
-                t->win = create_window(p->bg, 0, 0, NULL);
-
-                XMapWindow(ob_display, t->win);
-
-                p->targets = g_list_prepend(p->targets, t);
-                ++n;
+                    if (rit != rtlast)
+                        change = TRUE; /* order changed */
+                    break;
+                }
             }
+
+            if (!rit) {
+                gchar *text = popup_get_name(ft);
+
+                /* measure */
+                p->a_text->texture[0].data.text.string = text;
+                maxwidth = MAX(maxwidth, RrMinWidth(p->a_text));
+
+                if (!create_targets)
+                    g_free(text);
+                else {
+                    ObFocusCyclePopupTarget *t =
+                        g_new(ObFocusCyclePopupTarget, 1);
+
+                    t->client = ft;
+                    t->text = text;
+                    t->icon = client_icon(t->client);
+                    RrImageRef(t->icon); /* own the icon so it won't go away */
+                    t->win = create_window(p->bg, 0, 0, NULL);
+
+                    XMapWindow(ob_display, t->win);
+
+                    p->targets = g_list_prepend(p->targets, t);
+                    ++n;
+
+                    change = TRUE; /* added a window */
+                }
+            }
+        }
+    }
+
+    if (rtargets) {
+        change = TRUE; /* removed a window */
+
+        while (rtargets) {
+            popup_target_free(rtargets->data);
+            rtargets = g_list_delete_link(rtargets, rtargets);
         }
     }
 
     p->n_targets = n;
     p->maxtextw = maxwidth;
+
+    return change;
+}
+
+static void popup_cleanup(void)
+{
+    while(popup.targets) {
+        popup_target_free(popup.targets->data);
+        popup.targets = g_list_delete_link(popup.targets, popup.targets);
+    }
+    popup.n_targets = 0;
+    popup.last_target = NULL;
 }
 
 static gchar *popup_get_name(ObClient *c)
@@ -258,7 +317,7 @@ static void popup_render(ObFocusCyclePopup *p, const ObClient *c)
     gint innerw, innerh;
     gint i;
     GList *it;
-    const ObFocusCyclePopupTarget *newtarget;
+    const ObFocusCyclePopupTarget *newtarget = NULL;
     gint newtargetx, newtargety;
 
     screen_area = screen_physical_area_primary(FALSE);
@@ -451,8 +510,7 @@ void focus_cycle_popup_show(ObClient *c, gboolean iconic_windows,
 
     /* do this stuff only when the dialog is first showing */
     if (!popup.mapped)
-        popup_setup(&popup, TRUE, iconic_windows, all_desktops,
-                    dock_windows, desktop_windows);
+        popup_setup(&popup, TRUE, FALSE);
     g_assert(popup.targets != NULL);
 
     popup_render(&popup, c);
@@ -479,18 +537,7 @@ void focus_cycle_popup_hide(void)
 
     popup.mapped = FALSE;
 
-    while(popup.targets) {
-        ObFocusCyclePopupTarget *t = popup.targets->data;
-
-        RrImageUnref(t->icon);
-        g_free(t->text);
-        XDestroyWindow(ob_display, t->win);
-        g_free(t);
-
-        popup.targets = g_list_delete_link(popup.targets, popup.targets);
-    }
-    popup.n_targets = 0;
-    popup.last_target = NULL;
+    popup_cleanup();
 
     g_free(popup.hilite_rgba);
     popup.hilite_rgba = NULL;
@@ -510,8 +557,7 @@ void focus_cycle_popup_single_show(struct _ObClient *c,
     if (!popup.mapped) {
         Rect *a;
 
-        popup_setup(&popup, FALSE, iconic_windows, all_desktops,
-                    dock_windows, desktop_windows);
+        popup_setup(&popup, FALSE, FALSE);
         g_assert(popup.targets == NULL);
 
         /* position the popup */
@@ -536,16 +582,67 @@ void focus_cycle_popup_single_hide(void)
     icon_popup_hide(single_popup);
 }
 
-gboolean focus_cycle_popup_is_showing(ObClient *client)
+gboolean focus_cycle_popup_is_showing(ObClient *c)
 {
     if (popup.mapped) {
         GList *it;
 
         for (it = popup.targets; it; it = g_list_next(it)) {
             ObFocusCyclePopupTarget *t = it->data;
-            if (t->client == client)
+            if (t->client == c)
                 return TRUE;
         }
     }
     return FALSE;
 }
+
+static ObClient* popup_revert(ObClient *target)
+{
+    GList *it, *itt;
+
+    for (it = popup.targets; it; it = g_list_next(it)) {
+        ObFocusCyclePopupTarget *t = it->data;
+        if (t->client == target) {
+            /* move to a previous window if possible */
+            for (itt = it->prev; itt; itt = g_list_previous(itt)) {
+                ObFocusCyclePopupTarget *t2 = itt->data;
+                if (focus_cycle_valid(t2->client))
+                    return t2->client;
+            }
+
+            /* otherwise move to a following window if possible */
+            for (itt = it->next; itt; itt = g_list_next(itt)) {
+                ObFocusCyclePopupTarget *t2 = itt->data;
+                if (focus_cycle_valid(t2->client))
+                    return t2->client;
+            }
+
+            /* otherwise, we can't go anywhere there is nowhere valid to go */
+            return NULL;
+        }
+    }
+    return NULL;
+}
+
+ObClient* focus_cycle_popup_refresh(ObClient *target,
+                                    gboolean redraw)
+{
+    if (!popup.mapped) return NULL;
+
+    if (!focus_cycle_valid(target))
+        target = popup_revert(target);
+
+    redraw = popup_setup(&popup, TRUE, TRUE) && redraw;
+
+    if (!target && popup.targets)
+        target = ((ObFocusCyclePopupTarget*)popup.targets->data)->client;
+
+    if (target && redraw) {
+        popup.mapped = FALSE;
+        popup_render(&popup, target);
+        XFlush(ob_display);
+        popup.mapped = TRUE;
+    }
+
+    return target;
+}
