@@ -31,7 +31,7 @@ void mouse_shutdown(gboolean reconfig);
 
 gboolean mouse_bind(const gchar *buttonstr, const gchar *contextstr,
                     ObMouseAction mact, struct _ObActionsAct *action);
-void mouse_unbind_all();
+void mouse_unbind_all(void);
 
 void mouse_event(struct _ObClient *client, XEvent *e);
 
@@ -40,4 +40,9 @@ void mouse_grab_for_client(struct _ObClient *client, gboolean grab);
 ObFrameContext mouse_button_frame_context(ObFrameContext context,
                                           guint button, guint state);
 
+/*! If a replay pointer is needed, then do it.  Call this when windows are
+  going to be moving/appearing/disappearing, so that you know the mouse click
+  will go to the right window */
+void mouse_replay_pointer(void);
+
 #endif
