@@ -104,8 +104,25 @@ Rect *screen_physical_area_all_monitors(void);
 
 Rect *screen_physical_area_monitor(guint head);
 
+/*! Returns the monitor which contains the active window, or the one
+  containing the pointer otherwise. */
+guint screen_monitor_active(void);
+
 Rect *screen_physical_area_active(void);
 
+/*! Returns the primary monitor, as specified by the config.
+  @fixed If TRUE, then this will always return a fixed monitor, otherwise
+         it may change based on where focus is, or other heuristics.
+ */
+guint screen_monitor_primary(gboolean fixed);
+
+/*! Returns physical area for the primary monitor, as specified by the config.
+  @fixed If TRUE, then this will always use a fixed monitor as primary,
+         otherwise it may change based on where focus is, or other heuristics.
+         See screen_monitor_primary().
+*/
+Rect *screen_physical_area_primary(gboolean fixed);
+
 /* doesn't include struts which the search area is already outside of when
    'search' is not NULL */
 #define SCREEN_AREA_ALL_MONITORS ((unsigned)-1)
@@ -125,6 +142,9 @@ gboolean screen_physical_area_monitor_contains(guint head, Rect *search);
 */
 guint screen_find_monitor(Rect *search);
 
+/*! Finds the monitor which contains the point @x, @y */
+guint screen_find_monitor_point(guint x, guint y);
+
 /*! Sets the root cursor. This function decides which cursor to use, but you
   gotta call it to let it know it should change. */
 void screen_set_root_cursor(void);
@@ -133,4 +153,7 @@ void screen_set_root_cursor(void);
   is on this screen and FALSE if it is on another screen. */
 gboolean screen_pointer_pos(gint *x, gint *y);
 
+/*! Returns the monitor which contains the pointer device */
+guint screen_monitor_pointer(void);
+
 #endif
